Module: RubyCoded
- Defined in:
- lib/ruby_coded.rb,
lib/ruby_coded/plugins.rb,
lib/ruby_coded/version.rb,
lib/ruby_coded/chat/app.rb,
lib/ruby_coded/auth/pkce.rb,
lib/ruby_coded/chat/state.rb,
lib/ruby_coded/initializer.rb,
lib/ruby_coded/plugins/base.rb,
lib/ruby_coded/chat/renderer.rb,
lib/ruby_coded/tools/registry.rb,
lib/ruby_coded/chat/llm_bridge.rb,
lib/ruby_coded/strategies/base.rb,
lib/ruby_coded/tools/base_tool.rb,
lib/ruby_coded/plugins/registry.rb,
lib/ruby_coded/auth/auth_manager.rb,
lib/ruby_coded/chat/model_filter.rb,
lib/ruby_coded/errors/auth_error.rb,
lib/ruby_coded/initializer/cover.rb,
lib/ruby_coded/chat/input_handler.rb,
lib/ruby_coded/config/user_config.rb,
lib/ruby_coded/chat/state/messages.rb,
lib/ruby_coded/tools/system_prompt.rb,
lib/ruby_coded/chat/command_handler.rb,
lib/ruby_coded/tools/edit_file_tool.rb,
lib/ruby_coded/tools/read_file_tool.rb,
lib/ruby_coded/auth/callback_servlet.rb,
lib/ruby_coded/auth/providers/openai.rb,
lib/ruby_coded/chat/state/scrollable.rb,
lib/ruby_coded/chat/state/token_cost.rb,
lib/ruby_coded/tools/write_file_tool.rb,
lib/ruby_coded/auth/credentials_store.rb,
lib/ruby_coded/tools/delete_path_tool.rb,
lib/ruby_coded/tools/run_command_tool.rb,
lib/ruby_coded/chat/app/event_dispatch.rb,
lib/ruby_coded/auth/providers/anthropic.rb,
lib/ruby_coded/chat/renderer/chat_panel.rb,
lib/ruby_coded/chat/renderer/status_bar.rb,
lib/ruby_coded/chat/state/plan_tracking.rb,
lib/ruby_coded/tools/plan_system_prompt.rb,
lib/ruby_coded/chat/llm_bridge/plan_mode.rb,
lib/ruby_coded/strategies/oauth_strategy.rb,
lib/ruby_coded/tools/list_directory_tool.rb,
lib/ruby_coded/tools/tool_rejected_error.rb,
lib/ruby_coded/auth/oauth_callback_server.rb,
lib/ruby_coded/chat/state/model_selection.rb,
lib/ruby_coded/strategies/api_key_strategy.rb,
lib/ruby_coded/tools/agent_cancelled_error.rb,
lib/ruby_coded/tools/create_directory_tool.rb,
lib/ruby_coded/chat/renderer/model_selector.rb,
lib/ruby_coded/chat/renderer/plan_clarifier.rb,
lib/ruby_coded/chat/state/message_assistant.rb,
lib/ruby_coded/chat/state/tool_confirmation.rb,
lib/ruby_coded/chat/plan_clarification_parser.rb,
lib/ruby_coded/chat/renderer/chat_panel_input.rb,
lib/ruby_coded/chat/input_handler/modal_inputs.rb,
lib/ruby_coded/chat/llm_bridge/streaming_retries.rb,
lib/ruby_coded/chat/renderer/chat_panel_thinking.rb,
lib/ruby_coded/chat/state/message_token_tracking.rb,
lib/ruby_coded/plugins/command_completion/plugin.rb,
lib/ruby_coded/tools/agent_iteration_limit_error.rb,
lib/ruby_coded/chat/command_handler/plan_commands.rb,
lib/ruby_coded/chat/llm_bridge/tool_call_handling.rb,
lib/ruby_coded/chat/command_handler/agent_commands.rb,
lib/ruby_coded/chat/command_handler/model_commands.rb,
lib/ruby_coded/chat/command_handler/token_commands.rb,
lib/ruby_coded/chat/renderer/plan_clarifier_layout.rb,
lib/ruby_coded/chat/input_handler/normal_mode_input.rb,
lib/ruby_coded/chat/command_handler/history_commands.rb,
lib/ruby_coded/chat/command_handler/token_formatting.rb,
lib/ruby_coded/plugins/command_completion/input_extension.rb,
lib/ruby_coded/plugins/command_completion/state_extension.rb,
lib/ruby_coded/plugins/command_completion/renderer_extension.rb
Overview
This module contains the version of the RubyCoded gem
Defined Under Namespace
Modules: Auth, Chat, Errors, Plugins, Strategies, Tools Classes: Initializer, UserConfig
Constant Summary collapse
- VERSION =
"0.1.1"
Class Method Summary collapse
- .gem_version ⇒ Object
-
.plugin_registry ⇒ Object
Returns the global plugin registry.
-
.register_plugin(plugin_class) ⇒ Object
Register a plugin class that extends the chat functionality.
- .start ⇒ Object
Class Method Details
.gem_version ⇒ Object
7 8 9 |
# File 'lib/ruby_coded/version.rb', line 7 def self.gem_version Gem::Version.new(VERSION).freeze end |
.plugin_registry ⇒ Object
Returns the global plugin registry.
8 9 10 |
# File 'lib/ruby_coded/plugins.rb', line 8 def self.plugin_registry @plugin_registry ||= Plugins::Registry.new end |
.register_plugin(plugin_class) ⇒ Object
Register a plugin class that extends the chat functionality.
13 14 15 |
# File 'lib/ruby_coded/plugins.rb', line 13 def self.register_plugin(plugin_class) plugin_registry.register(plugin_class) end |
.start ⇒ Object
13 14 15 |
# File 'lib/ruby_coded.rb', line 13 def self.start Initializer.new end |