Module: RubyCoded::Chat::BridgeCommon::AutoSwitch

Defined in:
lib/ruby_coded/chat/bridge_common/auto_switch.rb

Overview

Recognizes "please implement the plan" style messages and switches the runtime from plan mode to agent mode so that write tools become available for execution.

Constant Summary collapse

IMPLEMENTATION_PATTERNS =
[
  /\bimplement/i,
  /\bgo ahead/i,
  /\bproceed/i,
  /\bexecut/i,
  /\bejecutar?/i,
  /\bcomenz/i,
  /\bcomienz/i,
  /\bhazlo/i,
  /\bconstru[iy]/i,
  /\badelante/i,
  /\bdale\b/i,
  /\bdo it/i,
  /\bbuild it/i
].freeze