Module: RubyCoded::Chat::Renderer::ModelSelector
- Included in:
- RubyCoded::Chat::Renderer
- Defined in:
- lib/ruby_coded/chat/renderer/model_selector.rb
Overview
This module contains the logic for rendering the UI model selector component
This module contains the logic for rendering the UI model selector component