Class: RubyCoded::Plugins::CommandCompletion::Plugin

Inherits:
Base
  • Object
show all
Defined in:
lib/ruby_coded/plugins/command_completion/plugin.rb

Overview

Built-in plugin that shows a filtered list of slash-command suggestions as the user types, with Tab to accept.

Class Method Summary collapse

Methods inherited from Base

command_descriptions, command_handler_extension, commands

Class Method Details

.input_extensionObject



17
# File 'lib/ruby_coded/plugins/command_completion/plugin.rb', line 17

def self.input_extension = InputExtension

.input_handler_methodObject



21
# File 'lib/ruby_coded/plugins/command_completion/plugin.rb', line 21

def self.input_handler_method = :handle_command_completion_input

.plugin_nameObject



13
# File 'lib/ruby_coded/plugins/command_completion/plugin.rb', line 13

def self.plugin_name = :command_completion

.render_methodObject



23
# File 'lib/ruby_coded/plugins/command_completion/plugin.rb', line 23

def self.render_method = :render_command_completer

.renderer_extensionObject



19
# File 'lib/ruby_coded/plugins/command_completion/plugin.rb', line 19

def self.renderer_extension = RendererExtension

.state_extensionObject



15
# File 'lib/ruby_coded/plugins/command_completion/plugin.rb', line 15

def self.state_extension = StateExtension